@@ -5,7 +5,7 @@
 #include "StringInputControl.h"
 #include "Motion/PostureEngine.h"
 
-//! Upon activation, saves the current position to a file name read from user (stored in /ms/data/motion/...)
+//! Upon activation, saves the current position to a file name read from user (default is /ms/data/motion...)
 class SavePostureControl : public StringInputControl {
  public:
 	//! Constructor
@@ -16,10 +16,7 @@ class SavePostureControl : public StringInputControl {
 	virtual ControlBase * takeInput(const std::string& msg) {
 		if(msg.size()>0) {
 			std::string filename;
-			if(msg[0]=='/')
-				filename=msg;
-			else
-				filename=config->motion.root+msg;
+			filename=config->motion.makePath(msg);
 			PostureEngine post;
 			post.takeSnapshot();
 			post.SaveFile(filename.c_str());
@@ -29,14 +26,14 @@ class SavePostureControl : public StringInputControl {
 };
 
 /*! @file
- * @brief Defines SavePostureControl, which when activated, saves the current position to a file name read from user (stored in /ms/data/motion/...)
+ * @brief Defines SavePostureControl, which when activated, saves the current position to a file name read from user (default is /ms/data/motion...)
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2004/01/08 22:39:55 $
+ * $Date: 2004/01/30 01:29:41 $
  */
 
 #endif
