@@ -10,6 +10,7 @@
 #include "Events/EventRouter.h"
 #include "Motion/PostureMC.h"
 #include "Shared/ERS210Info.h"
+#include "Shared/ERS7Info.h"
 
 //! just a little demo behavior which lifts a leg higher as more pressure is put on a head button
 /*! Based on an idea from Alan Chun-ho Ho for a basic demo program */
@@ -26,7 +27,7 @@ public:
 		//now do your code:
 		
 		// creates a PostureMC class to move the joint(s) and adds it to global MotionManager
-		pose_id=motman->addMotion(SharedObject<PostureMC>());
+		pose_id=motman->addMotion(SharedObject<PostureMC>(),false);
 		// subscribe to sensor updated events through the global EventRouter
 		erouter->addListener(this,EventBase::sensorEGID,SensorSourceID::UpdatedSID);
 	}
@@ -43,10 +44,6 @@ public:
 	virtual void processEvent(const EventBase& event) {
 		// to be more general, let's check that it's the right event:
 		if(event.getGeneratorID()==EventBase::sensorEGID) {
-			//only really works on the 210 model - the others don't have a proper pressure sensor
-			//(the 220's antenna-thing is close, but doesn't give a continuous range)
-			if( !(state->robotDesign&WorldState::ERS210Mask) )
-				return;
 			//we'll need to specify the ERS210Info namespace below when
 			//referencing the button offsets so that this will compile for
 			//the ERS-7 as well (which lacks front and back head buttons),
@@ -57,13 +54,25 @@ public:
 			// (this is the PostureMC we created in DoStart())
 			MMAccessor<PostureMC> pose_mc(pose_id);
 			
-			//Joint offsets are defined in ERS210Info.h, ERS220Info.h and ERS2xxInfo.h
+			//Joint offsets are defined in ERS210Info.h, ERS220Info.h, ERS2xxInfo.h, and ERS7Info.h
 			unsigned int joint=LFrLegOffset+RotatorOffset;
 			
 			//state is a global instantiation of WorldState, kept up to date by framework;
 			//pressure is in range 0 to 1 - we use the pressure on the front head button here
-			float pressure=state->buttons[ERS210Info::HeadFrButOffset];
-			std::cout << "HeadFrBut Pressure: " << pressure << std::endl;
+			float pressure=0;
+			if(state->robotDesign&WorldState::ERS210Mask) {
+				pressure=state->buttons[ERS210Info::HeadFrButOffset];
+				std::cout << "HeadFrBut Pressure: " << pressure << std::endl;
+			} else if(state->robotDesign&WorldState::ERS7Mask) {
+				pressure=state->buttons[ERS7Info::HeadButOffset];
+				std::cout << "HeadBut Pressure: " << pressure << std::endl;
+			} else {
+				//only really works on the ERS-210 or ERS-7 models - the others don't have a proper pressure sensor
+				//(the 220's antenna-thing is close, but doesn't give a continuous range)
+				std::cout << "Unknown model" << std::endl;
+				erouter->forgetListener(this); // stops getting events (and timers, if we had any)
+				return;
+			}
 			
 			//outputRanges is a constant table, also defined in ERS210Info.h or ERS220Info.h
 			float angle=outputRanges[joint][MaxRange]*pressure;
@@ -74,7 +83,10 @@ public:
 			//let's do the whole thing again with the other head button for the other leg:
 			// (cutting out a some of the intermediary steps this time)
 			joint=RFrLegOffset+RotatorOffset;
-			pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[ERS210Info::HeadBkButOffset]);
+			if(state->robotDesign&WorldState::ERS210Mask)
+				pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[ERS210Info::HeadBkButOffset]);
+			else if(state->robotDesign&WorldState::ERS7Mask) //ERS7 doesn't have another head button, we'll use one of its back buttons
+				pose_mc->setOutputCmd(joint,outputRanges[joint][MaxRange]*state->buttons[ERS7Info::FrontBackButOffset]);
 
 			// notice that there's no "check in" for pose_mc
 			// MMAccessor's destructor does this automatically
@@ -104,10 +116,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.9 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:42 $
+ * $Date: 2004/02/06 04:06:50 $
  */
 
 #endif
