@@ -44,9 +44,9 @@ void FollowHeadBehavior::DoStop() {
 void FollowHeadBehavior::processEvent(const EventBase& e) {
 	if(e==clock) {
 		//x,y,a are percentage of maximum speed in that direction
-		double x = -(state->outputs[HeadOffset+TiltOffset]/outputRanges[HeadOffset+TiltOffset][1]);
-		double y = state->outputs[HeadOffset+RollOffset]/outputRanges[HeadOffset+RollOffset][1];
-		double a = state->outputs[HeadOffset+PanOffset]/outputRanges[HeadOffset+PanOffset][1];
+		float x=-(state->outputs[HeadOffset+TiltOffset]-outputRanges[HeadOffset+TiltOffset][MinRange])/(outputRanges[HeadOffset+TiltOffset][MaxRange]-outputRanges[HeadOffset+TiltOffset][MinRange])*2+1;
+		float y=(state->outputs[HeadOffset+RollOffset]-outputRanges[HeadOffset+RollOffset][MinRange])/(outputRanges[HeadOffset+RollOffset][MaxRange]-outputRanges[HeadOffset+RollOffset][MinRange])*2-1;
+		float a=(state->outputs[HeadOffset+PanOffset]-outputRanges[HeadOffset+PanOffset][MinRange])/(outputRanges[HeadOffset+PanOffset][MaxRange]-outputRanges[HeadOffset+PanOffset][MinRange])*2-1;
 		MMAccessor<WalkMC> walk(walker_id);
 		walk.mc()->setTargetVelocity(x*WalkMC::MAX_DX,y*WalkMC::MAX_DY,a*WalkMC::MAX_DA);
 
@@ -74,8 +74,8 @@ void FollowHeadBehavior::processEvent(const EventBase& e) {
  *
  * $Author: ejt $
  * $Name $
- * $Revision: 1.4 $
- * $State: Rel $
- * $Date: 2003/09/25 15:26:23 $
+ * $Revision: 1.5 $
+ * $State: Exp $
+ * $Date: 2004/01/06 01:00:44 $
  */
 
