@@ -20,13 +20,13 @@ void HeadPointControllerBehavior::runCommand(unsigned char *command) {
 	// Find out what type of command this is
 	switch(command[0]) {
 	case CMD_tilt:
-		t = param*outputRanges[HeadOffset+TiltOffset][param>0?MaxRange:MinRange];
+		t = fabs(param)*outputRanges[HeadOffset+TiltOffset][param>0?MaxRange:MinRange];
 		break;
 	case CMD_pan:
-		p = param*outputRanges[HeadOffset+PanOffset][param>0?MaxRange:MinRange];
+		p = fabs(param)*outputRanges[HeadOffset+PanOffset][param>0?MaxRange:MinRange];
 		break;
 	case CMD_roll:
-		r = param*outputRanges[HeadOffset+RollOffset][param>0?MaxRange:MinRange];
+		r = fabs(param)*outputRanges[HeadOffset+RollOffset][param>0?MaxRange:MinRange];
 		break;
 	default:
 		cout << "MECHA: unknown command " << command[0] << endl;
@@ -123,9 +123,9 @@ int HeadPointControllerBehavior::mechacmd_callback(char *buf, int bytes) {
  * @author tss (Creator)
  * 
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.3 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.4 $
  * $State: Exp $
- * $Date: 2004/01/19 19:43:50 $
+ * $Date: 2004/02/05 01:51:39 $
  */
 
