@@ -1,7 +1,6 @@
 #include "RawCamBehavior.h"
 #include "Wireless/Wireless.h"
 #include "Events/EventRouter.h"
-#include "Shared/Config.h"
 #include "Vision/RawCameraGenerator.h"
 #include "Vision/JPEGGenerator.h"
 #include "Events/FilterBankEvent.h"
@@ -19,10 +18,7 @@ RawCamBehavior::DoStart() {
   wireless->setDaemon(visRaw,true);
   wireless->listen(visRaw,config->vision.rawcam_port);
 	
-	//we're going to make the ControllerGUI open these itself...
-	//std::vector<std::string> args;
-	//args.push_back("raw");
-	//Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",config->vision.rawcam_port,args);
+	Controller::loadGUI("org.tekkotsu.mon.VisionGUI","RawVisionGUI",config->vision.rawcam_port);
 
 	erouter->addListener(this,EventBase::visRawCameraEGID,ProjectInterface::visRawCameraSID);
 	erouter->addListener(this,EventBase::visJPEGEGID,ProjectInterface::visColorJPEGSID);
@@ -32,7 +28,7 @@ RawCamBehavior::DoStart() {
 void
 RawCamBehavior::DoStop() {
 	erouter->forgetListener(this);
-	//Controller::closeGUI("RawVisionGUI");
+	Controller::closeGUI("RawVisionGUI");
 
 	// this could be considered a bug in our wireless - if we don't setDaemon(...,false)
 	// it will try to listen again even though we explicitly closed the server socket...
@@ -272,9 +268,9 @@ RawCamBehavior::closePacket() {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.8 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.10 $
  * $State: Exp $
- * $Date: 2004/01/07 22:51:49 $
+ * $Date: 2004/02/05 19:11:26 $
  */
 
