@@ -387,7 +387,7 @@ MMCombo::ReadySendJoints(const OReadyEvent& sysevent) {
 			// for instance, this virtual mode thing, which is global to all the affected LEDs
 			OLED3Mode curMode[NumFrames];
 			for(unsigned int frame=0; frame<NumFrames; frame++)
-				curMode[frame]=(calcLEDValue(ERS7Info::LEDABModeOffset-LEDOffset,outputs[frame][ERS7Info::LEDABModeOffset])==oledON?oled3_MODE_B:oled3_MODE_A);
+				curMode[frame]=(calcLEDValue(ERS7Info::LEDABModeOffset-LEDOffset,sqrt(clipRange01(outputs[frame][ERS7Info::LEDABModeOffset])))==oledON?oled3_MODE_B:oled3_MODE_A);
 			for(unsigned int i=ERS7Info::FaceLEDPanelOffset; i<LEDOffset+NumLEDs; i++)
 				if(open[i]) {
 					OLEDCommandValue3* jval = reinterpret_cast<OLEDCommandValue3*>(cmdVecData->GetData(used)->value);
@@ -730,10 +730,10 @@ MMCombo::RPOPENR_send(char *buf, int bufsize) {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.48 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.49 $
  * $State: Exp $
- * $Date: 2004/01/19 20:35:45 $
+ * $Date: 2004/02/02 20:55:50 $
  */
 
 
