@@ -102,6 +102,7 @@ protected:
 	//! Motion only, maintains the activation level of the LEDs, returns whether it should be 'fired'
 	inline OLEDValue calcLEDValue(unsigned int i,float x) {
 		if(x<=0.0) {
+			ledActivation[i]*=.9; //decay activation... resets to keeps LEDs in sync, looks a little better
 			return oledOFF;
 		} else if(x>=1.0) {
 			return oledON;
@@ -137,10 +138,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.24 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.25 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:57 $
+ * $Date: 2004/02/03 01:17:24 $
  */
 
 #endif
