@@ -60,7 +60,9 @@ class LedEngine {
 	//!sets the leds specified by @a leds to @a value for @a ms milliseconds, then sets back.  Clears ~leds
 	void cflash(LEDBitMask_t leds, float value, unsigned int ms);
 	//!sets the leds specified by @a leds to @a value for @a ms milliseconds, then sets back.
-	void flash(LEDBitMask_t leds, unsigned int ms=500);
+	void flash(LEDBitMask_t leds, float value, unsigned int ms);
+	//!sets the leds specified by @a leds to either a much higher or much lower value for @a ms milliseconds, then sets back.
+	void flash(LEDBitMask_t leds, unsigned int ms);
 	//!causes the leds specified by @a leds to cycle between low and high, clears others.  See cycle() for parameter documentation.
 	inline void ccycle(LEDBitMask_t leds, unsigned int period, float amp, float offset=0, int phase=0) { clear(); cycle(leds,period,amp,offset,phase); }
 	//!causes the leds specified by @a leds to cycle between low and high
@@ -161,10 +163,10 @@ class LedEngine {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.11 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.12 $
  * $State: Exp $
- * $Date: 2003/12/23 06:33:42 $
+ * $Date: 2004/02/03 01:17:57 $
  */
 
 #endif
