@@ -52,7 +52,7 @@ unsigned int LoadSave::LoadFile(const char* file) {
 		std::cout << "*** WARNING could not open file for loading \"" << file << "\"" << std::endl;
 		return 0;
 	}
-	unsigned int sz = LoadFile(f);
+	unsigned int sz = LoadFileStream(f);
 	if(sz==0)
 		std::cout << "*** WARNING loading of " << file << " failed " << std::endl;
 	err=fclose(f);
@@ -70,7 +70,7 @@ unsigned int LoadSave::SaveFile(const char* file) const {
 		std::cout << "*** WARNING could not open file for saving \"" << file << "\"" << std::endl;
 		return 0;
 	}
-	unsigned int sz = SaveFile(f);
+	unsigned int sz = SaveFileStream(f);
 	if(sz==0)
 		std::cout << "*** WARNING saving of " << file << " failed " << std::endl;
 	err=fclose(f);
@@ -81,7 +81,7 @@ unsigned int LoadSave::SaveFile(const char* file) const {
 	return sz;
 }
 
-unsigned int LoadSave::LoadFile(FILE* f) {
+unsigned int LoadSave::LoadFileStream(FILE* f) {
 	unsigned int cap=128;
 	unsigned int sz=0;
 	unsigned int origpos=ftell(f);
@@ -111,7 +111,7 @@ unsigned int LoadSave::LoadFile(FILE* f) {
 		fseek(f,origpos+resp,SEEK_SET);
 	return resp;
 }
-unsigned int LoadSave::SaveFile(FILE* f) const {
+unsigned int LoadSave::SaveFileStream(FILE* f) const {
 	unsigned int sz=getBinSize();
 	char * buf = new char[sz];
 	memset(buf,0xF0,sz);
@@ -137,9 +137,9 @@ unsigned int LoadSave::SaveFile(FILE* f) const {
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.3 $
- * $State: Rel $
- * $Date: 2003/09/25 15:31:53 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.4 $
+ * $State: Exp $
+ * $Date: 2004/02/03 01:19:05 $
  */
 
