@@ -5,8 +5,105 @@
 #include <string>
 
 //! Intended as an interface to allow easy and uniform file operations
-/*! Be mindful of version differences - better safe than sorry - put a
- *  version number as the first field, just in case */
+/*!
+	
+	Generally, for usage, all you need to know is to call
+	<tt>SaveFile("/path/to/file.ext")</tt> or
+	<tt>SaveBuffer(membuffer)</tt> in order to have the class serialize
+	itself, and the LoadFile() / LoadBuffer() in order to reload the
+	data.
+	
+	So, when SaveFile() is called, it checks that it
+	can open the specified file, and then calls SaveFileStream()
+	with the open file.  This will then check getBinSize(), create a
+	buffer of that size, and call SaveBuffer() to do the actual work of
+	serialization into that buffer.  If SaveBuffer is successful (make
+	sure your getBinSize() doesn't underestimate!) SaveFileStream()
+	copies the buffer out to the file, and then finally, SaveFile() will
+	close the file.
+	
+  This has the nice side effect that if you want to send the data over
+  the network instead of a file, you can call SaveBuffer() directly
+  and reuse the code.  However, if you have a lot of data to save, you
+  can override the SaveFileStream() function as well, and save into
+  the file directly.  So far I've only bothered to do that with
+  only a few classes.
+	
+	The recommended style for using LoadSave in classes with inheritance
+	is to have each subclass first call the superclass's implementation,
+	and then save their own local data.  This compartmentalizes the data
+	access and makes it easy to maintain - the code that serializes is
+	right in with the code that defines the structure.  If you change
+	one, it's easy to see where to change the other.  And protection
+	between levels of inheritance is retained.  (This is why I say it's
+	highly flexible/maintainable, but poor readability since the
+	serialization is all broken up.)
+	
+	I also recommend putting a little string header at the beginning of
+	each class's info.  This will allow polymorphism when loading files
+	(you can look at the string and create the appropriate type) but
+	also is handy for checking field alignment... it's a lot easier to
+	tell how much you're offset within a string than to do the same with
+	a stream of binary values.  Further, you can use the string as
+	version information if you want to be backward compatible in future
+	versions of your code.
+	
+	LoadSave provides a series of encode and decode functions for all
+	the primitive types.  This will handle copying the value into the
+	buffer or file, and can provide platform independence through byte
+	swapping if needed (there's a compiler flag you can set for
+	platforms that have the opposite byte order).  Most of these are
+	pretty straightfoward - an int is just 4 bytes and so on.
+	
+	However, there's one caveat that I want to make sure to point out if
+	you have to write parsing code in say, Java.  Strings are encoded by
+	first storing an int to hold the string's length, then the string
+	itself, and then a null character.  This adds 5 bytes to the length
+	of any string, but makes loading the files much easier/faster - you
+	can call string library functions directly on the buffer if it's
+	already in memory since the string is null terminated, or can
+	allocate memory to hold the string during loading from a file if
+	needed because you'll know the size of the string before you get to
+	it.
+	
+	Of course, the string stuff is transparent if you just use
+	LoadSave's encode/decode functions to parse it.  But if that's not
+	available (for instance if your receiver is in Java, there's a
+	readLoadSaveString() in VisionListener.java if that will help:
+	http://cvs.tekkotsu.org/cgi-bin/viewcvs.cgi/Tekkotsu/tools/mon/org/tekkotsu/mon/VisionListener.java?rev=1.6&content-type=text/vnd.viewcvs-markup
+	@code
+	public boolean _isConnected;
+
+	public String readLoadSaveString(InputStream in) throws java.io.IOException {
+		int creatorLen=readInt(in);
+		if(!_isConnected) return ""; 
+		String creator=new String(readBytes(in,creatorLen));
+		if(!_isConnected) return "";
+		if(readChar(in)!='\0')
+			System.err.println("Misread LoadSave string? "+creator);
+		return creator;
+	}
+
+	public int readInt(InputStream in) throws IOException {
+		int read=0;
+		int last=0;
+		byte[] buf=new byte[4];
+		while (read<4 && last>=0) { last=in.read(buf,read,4-read); read+=last; }
+		if(last<0)
+			_isConnected=false;
+		return (b2i(buf[3])<<24) | (b2i(buf[2])<<16) |
+					 (b2i(buf[1])<< 8) | b2i(buf[0]);
+	}
+  public byte[] readBytes(InputStream in, int bytes) throws IOException {
+    byte[] ret=new byte[bytes];
+    readBytes(ret, in, bytes);
+    return ret;
+  }
+	public char readChar(InputStream in) throws IOException {
+		return (char)in.read();
+	}
+	@endcode
+*/
 class LoadSave {
  public:
 	//! This is the amount of extra space needed to store a string (int for len of string plus 1 for null term
@@ -53,7 +150,7 @@ class LoadSave {
 	 *  leaf-level ones won't even get this call unless you override the ones
 	 *  above them - hence, this is all or nothing
 	 *	@return number of bytes read, 0 if error (or empty) */
-	virtual unsigned int LoadFile(FILE* f);
+	virtual unsigned int LoadFileStream(FILE* f);
 	//!Used recursively on member objects once a file is already open - DON'T CLOSE the file in your overridden functions
 	/*! @param f a pointer to the file to save
 	 *  @warning could potentially be very inefficient if root-level objects
@@ -61,7 +158,7 @@ class LoadSave {
 	 *  leaf-level ones won't even get this call unless you override the ones
 	 *  above them - hence, this is all or nothing
 	 *	@return number of bytes written, 0 if error (or empty) */
-	virtual unsigned int SaveFile(FILE* f) const;
+	virtual unsigned int SaveFileStream(FILE* f) const;
 	//@}
 
 	//! These are for putting creator codes at the beginning of your data to check for sanity, just optional
@@ -108,8 +205,8 @@ class LoadSave {
 	/*!@brief encode or decode with byte order consistancy*/
 	inline static unsigned int encode(const LoadSave& x, char buf[], unsigned int cap)  { return x.SaveBuffer(buf,cap); }
 	inline static unsigned int decode(LoadSave& x, const char buf[], unsigned int cap)  { return x.LoadBuffer(buf,cap); }
-	inline static unsigned int encode(const LoadSave& x, FILE* f)                  { return x.SaveFile(f); }
-	inline static unsigned int decode(LoadSave& x, FILE* f)                        { return x.LoadFile(f); }
+	inline static unsigned int encode(const LoadSave& x, FILE* f)                  { return x.SaveFileStream(f); }
+	inline static unsigned int decode(LoadSave& x, FILE* f)                        { return x.LoadFileStream(f); }
 	
 	//I don't know what compiler flag to use - this one is fake.
 	//Ideally, we should be able to detect host orientation
@@ -233,10 +330,10 @@ protected:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.6 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.8 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:58 $
+ * $Date: 2004/02/05 23:33:45 $
  */
 
 #endif
