@@ -132,16 +132,18 @@ RLEGenerator::setNumImages(unsigned int nLayers, unsigned int nChannels) {
 	}
 }
 
+//! simply creates a new data region and returns it
 unsigned char *
 RLEGenerator::createImageCache(unsigned int layer, unsigned int /*chan*/) const {
 	return reinterpret_cast<unsigned char*>(new run[maxRuns[layer]]);
 }
 
+//! a single call to the CMVision library to do the work, and we're done.
 void
 RLEGenerator::calcImage(unsigned int layer, unsigned int chan) const {
 	PROFSECTION("RLEGenerator::calcImage(...)",state->mainProfile);
   numRuns[layer][chan] = CMVision::EncodeRuns(reinterpret_cast<run*>(images[layer][chan]),src->getImage(layer,chan),getWidth(layer),getHeight(layer),maxRuns[layer]);
-	imageValids[layer][chan]=true;
+	imageValids[layer][chan]=true; // <--- don't forget to do this, otherwise you'll recompute on every access, even if the cache is still valid
 }
 
 void
@@ -161,9 +163,9 @@ RLEGenerator::destruct() {
  * @author ejt (reorganized)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.5 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.6 $
  * $State: Exp $
- * $Date: 2004/01/16 07:39:51 $
+ * $Date: 2004/02/05 02:37:09 $
  */
 
