@@ -10,7 +10,7 @@ class OFbkImageInfo;
 //! Generates FilterBankEvents containing raw camera images directly from the system (doesn't make a copy)
 class RawCameraGenerator : public FilterBankGenerator {
 public:
-	//!constructor, numRawLayers is the number of real layers passed from the system, numCalcLayers is the total number of layers to make available
+	//! constructor, numRawLayers is the number of real layers passed from the system, numCalcLayers is the total number of layers to make available
 	/*! The extra calculated layers are simply created by giving larger
 	 *  increments, they reference the same data (no computational cost,
 	 *  marginal memory costs... it's just nice to have more layers in
@@ -23,7 +23,10 @@ public:
 	 *  The top most layer (largest index) is a double-scale image.  For
 	 *  the Y-channel, it is reconstructed from the 4 Y channels.  For
 	 *  the other channels, it just does a fast scaling (but these
-	 *  operations do cost, so use the top layer conservatively. */
+	 *  operations do cost, so use the top layer conservatively.
+	 *
+	 *  @see FilterBankGenerator for information on serialization format
+	 */
 	RawCameraGenerator(unsigned int numRawLayers, unsigned int numCalcLayers, EventBase::EventGeneratorID_t gid, unsigned int sid, unsigned int mysid);
 
 	//! destructor
@@ -54,7 +57,23 @@ public:
 
 	virtual unsigned int SaveBuffer(char buf[], unsigned int len) const;
 
+	virtual unsigned int SaveFileStream(FILE* f) const; //!< overrridden to allow saving direct to file without an extra buffer copy
+
 protected:
+	//! ohh, this is so yucky.  But we need to get around heap allocation bugs with large regions in Aperios :(
+	/*! So we store the double size images statically within the class.
+	 *  What a waste of memory since we're probably not using these very
+	 *  much, and they are rather large... :(
+	 * 
+	 *  The 2.0 release had the proper dynamic allocation
+	 *  implementation, but has been replaced in 2.0.1 with this static
+	 *  allocation so it won't crash.
+	 *
+	 *  Of course, if the memory allocation bug is never fixed, and
+	 *  camera sizes increase in later models, this will have to be
+	 *  modified. */
+	unsigned char dblRes[NUM_CHANNELS][416][320]; 
+
 	virtual void setNumImages(unsigned int nLayers, unsigned int nChannels);
 
 	virtual void setDimensions(); //!< resets the width, height, skip and stride values
@@ -93,10 +112,10 @@ private:
  * @author ejt (Creator)
  *
  * $Author: ejt $
- * $Name: tekkotsu-2_0 $
- * $Revision: 1.10 $
+ * $Name: tekkotsu-2_0_1 $
+ * $Revision: 1.13 $
  * $State: Exp $
- * $Date: 2004/01/18 10:16:59 $
+ * $Date: 2004/02/05 23:33:48 $
  */
 
 #endif
