@@ -72,11 +72,12 @@ public class VisionTrain extends JFrame {
 
     ImageData imageData=new ImageData();
 
+		//Thanks to martin.mueller at mni.fh-giessen.de for the bug fix:
 		if(isRGB)
-			imageData.loadFullRGBFiles(files);
+			imageData.loadFullRGBFilesAsRGB(files);
 		else 
-			imageData.loadFullYUVFiles(files);
-    trainCanvas.plotImage(imageData.getHS(), imageData.getRGB());
+			imageData.loadFullYUVFilesAsRGB(files);
+    trainCanvas.plotImage(imageData.getHS(), imageData.getPixels());
   }
 }
 
